"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const getPackageJSON_1 = __importDefault(require("../utils/getPackageJSON"));
function getDepsStr(deps) {
    if (Array.isArray(deps)) {
        return deps.reduce((output, name) => {
            return output += `\n${name}`;
        }, '');
    }
    else {
        return Object.entries(deps).reduce((output, [name, version]) => {
            return output += `\n${chalk_1.default.bold(name)} v${version.slice(1)}`;
        }, '');
    }
}
function genInfoOutput(info) {
    let output = chalk_1.default.blue.bold(info.name);
    output += chalk_1.default.blue(` v${info.version}`);
    let depsEmpty = true;
    if (info.description) {
        output += `\n${info.description}`;
    }
    if (info.dependencies) {
        depsEmpty = false;
        output += `\n\n${chalk_1.default.green.bold('Dependencies:')}`;
        output += getDepsStr(info.dependencies);
    }
    if (info.devDependencies) {
        depsEmpty = false;
        output += `\n\n${chalk_1.default.yellow.bold('Dev dependencies:')}`;
        output += getDepsStr(info.devDependencies);
    }
    if (info.bundledDependencies || info.peerDependencies || info.optionalDependencies) {
        depsEmpty = false;
        output += `\n\n${chalk_1.default.bold('Other dependencies(peer, bundle, optional)')}`;
        output += info.bundledDependencies ? getDepsStr(info.bundledDependencies) : '';
        output += info.peerDependencies ? getDepsStr(info.peerDependencies) : '';
        output += info.optionalDependencies ? getDepsStr(info.optionalDependencies) : '';
    }
    if (depsEmpty) {
        output += `\n\n${chalk_1.default.red('No dependencies found in project')}`;
    }
    return output;
}
function InfoHandler(path) {
    const package_info = getPackageJSON_1.default(path);
    if (!package_info) {
        console.log(`${chalk_1.default.red.bold('Error:')} no package.json found in this directory`);
        return;
    }
    console.log(genInfoOutput(package_info));
}
exports.default = InfoHandler;
