"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getPackageJSON_1 = __importDefault(require("../utils/getPackageJSON"));
const chalk_1 = __importDefault(require("chalk"));
const inquirer_1 = __importDefault(require("inquirer"));
const child_process_1 = require("child_process");
const util = __importStar(require("util"));
const ora_1 = __importDefault(require("ora"));
const asyncExec = util.promisify(child_process_1.exec);
function searchInput() {
    let input = [];
    input.push({
        name: "search",
        type: "input",
        message: "Input package name you want to install",
    });
    return inquirer_1.default.prompt(input);
}
function selectInput(info) {
    let input = [];
    input.push({
        type: 'list',
        name: 'selected_package',
        message: 'Choose package:',
        choices: info.map((info) => {
            return info.name;
        }, []),
        default: info[0].name
    });
    input.push({
        type: 'list',
        name: 'dep_type',
        message: 'Choose dependency type:',
        choices: ['Production', 'Development'],
        default: 'Production'
    });
    return inquirer_1.default.prompt(input);
}
function InstallHandler(path) {
    const package_info = getPackageJSON_1.default(path);
    if (!package_info) {
        console.log(`${chalk_1.default.red.bold('Error:')} no package.json found in this directory`);
        return;
    }
    const spinner = ora_1.default();
    spinner.color = 'blue';
    searchInput()
        .then((answers) => {
        spinner.start('Searching');
        const typedAnswers = answers;
        return asyncExec(`npm search --json ${typedAnswers.search}`);
    })
        .then(({ stdout, stderr }) => {
        if (stderr) {
            return Promise.reject(new Error(stderr));
        }
        spinner.stop();
        if (stdout === "\n]\n\n") {
            return Promise.reject(new Error('No packages found'));
        }
        return selectInput(JSON.parse(stdout));
    })
        .then(answers => {
        const typedAnswers = answers;
        spinner.start('Installing');
        if (typedAnswers.dep_type === 'Production') {
            return asyncExec(`npm i --prefix ${path} ${typedAnswers.selected_package}`);
        }
        else {
            return asyncExec(`npm i ${typedAnswers.selected_package} -D`);
        }
    })
        .then(({ stdout, stderr }) => {
        if (stderr) {
            return Promise.reject(new Error(stderr));
        }
        if (stdout.includes('up to date')) {
            spinner.fail(chalk_1.default.bold.yellow('ALREADY INSTALLED'));
        }
        else {
            spinner.succeed(chalk_1.default.bold.green("PACKAGE INSTALLED"));
        }
    })
        .catch(err => {
        console.error(`${chalk_1.default.red.bold('Error: ')} ${err.message}`);
    });
}
exports.default = InstallHandler;
